==> dde-shell_2.0.3.tar.xz: BUILD/panels/dock/translations/org.deepin.ds.dock_zh_TW.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_TW">
<context>
    <name>main</name>
    <message>
        <source>Indicator Style</source>
        <translation>指示器樣式</translation>
    </message>
    <message>
        <source>Fashion Mode</source>
        <translation>時尚模式</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>高效模式</translation>
    </message>
    <message>
        <source>Classic Mode</source>
        <translation>經典模式</translation>
    </message>
    <message>
        <source>Centered Mode</source>
        <translation>居中模式</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>左</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>位置</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>模式</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>上</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>下</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>右</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>狀態</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>壹直顯示</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>壹直隱藏</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>智能隱藏</translation>
    </message>
    <message>
        <source>Dock Settings</source>
        <translation>任務欄設置</translation>
    </message>
    <message>
        <source>Lock the Dock</source>
        <translation>禁用自由調節</translation>
    </message>
</context>
</TS>

==> dde-shell_2.0.15.tar.xz: BUILD/panels/dock/translations/org.deepin.ds.dock_zh_TW.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_TW">
<context>
    <name>main</name>
    <message>
        <source>Indicator Style</source>
        <translation>指示器樣式</translation>
    </message>
    <message>
        <source>Fashion Mode</source>
        <translation>時尚模式</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>高效模式</translation>
    </message>
    <message>
        <source>Classic Mode</source>
        <translation>經典模式</translation>
    </message>
    <message>
        <source>Centered Mode</source>
        <translation>居中模式</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>左</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>位置</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>模式</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>上</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>下</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>右</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>狀態</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>壹直顯示</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>壹直隱藏</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>智能隱藏</translation>
    </message>
    <message>
        <source>Dock Settings</source>
        <translation>任務欄設置</translation>
    </message>
    <message>
        <source>Lock the Dock</source>
        <translation>停用自由調節</translation>
    </message>
</context>
</TS>
